@@ -4,7 +4,7 @@ import argparse
 import numpy as np
 import cv2
 from cv2 import aruco
-from Calibrations.Camera2ScreenCalib import calib
+from GhostScan.Calibrations.Camera2ScreenCalib import calib
 # from Camera2ScreenCalib import calib
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
@@ -49,4 +49,4 @@ def geoCalibII(geoCalibImgUndistortFile, displayintersect, displayScaleFactor):
     fig.savefig(imgSavePath + '/comparation' + '.png')
     plt.show()
 
-    #return display_intersect_mat, cam_mirror_intersect_mat, rcamera_dis, tcamera_dis
\ No newline at end of file
+    #return display_intersect_mat, cam_mirror_intersect_mat, rcamera_dis, tcamera_dis
