@@ -20,6 +20,15 @@ class RadiometricCalibSession(CalibrationSession, ABC):
 
     def capture(self):
         # For radiometric calibration a series of differently exposed images of the same object is required
+        if not os.path.exists('CalibrationImages/Radiometric/'):
+            os.mkdir('CalibrationImages/Radiometric/')
+        if not os.path.exists('CapturedImages/Radiometric/'):
+            os.mkdir('CapturedImages/Radiometric/')
+        if not os.path.exists('CalibrationNumpyData/Radiometric/'):
+            os.mkdir('CalibrationNumpyData/Radiometric/')
+        if not os.path.exists('CapturedNumpyData/Radiometric/'):
+            os.mkdir('CapturedNumpyData/Radiometric/')
+            
         for exp in self.exposures:
             self.camera.setExposure(exp)
             self.camera.getImage(name='Radiometric/'+str(exp),calibration=True)
