@@ -66,14 +66,6 @@ class Internal(Camera, ABC):
         self.resolution = resolution
 
     def getImage(self, path="", saveImage=True, saveNumpy=True, calibration=False, timeout=5000):
-        if not os.path.exists('CalibrationImages/' + path):
-            os.mkdir('CalibrationImages/' + path)
-        if not os.path.exists('CapturedImages/' + path):
-            os.mkdir('CapturedImages/' + path)
-        if not os.path.exists('CalibrationNumpyData/' + path):
-            os.mkdir('CalibrationNumpyData/' + path)
-        if not os.path.exists('CapturedNumpyData/' + path):
-            os.mkdir('CapturedNumpyData/' + path)
         
         # Grab current frame
         ret, frame = self.cap.read()
